from wazen._async_client import AsyncWazen
from wazen._client import Wazen
from wazen._core._errors import WazenApiError, WazenNetworkError, WazenTimeoutError
from wazen._core._types import PaginatedResponse
from wazen._version import __version__

__all__ = [
    "__version__",
    "Wazen",
    "AsyncWazen",
    "WazenApiError",
    "WazenTimeoutError",
    "WazenNetworkError",
    "PaginatedResponse",
]



from __future__ import annotations

from typing import Any

from wazen._core._types import PaginatedResponse
from wazen.resources._base import AsyncResource, SyncResource, _filter_none


class Webhooks(SyncResource):
    def create(self, *, url: str, events: list[str], session_id: str | None = None) -> dict[str, Any]:
        body = _filter_none({"url": url, "events": events, "session_id": session_id})
        return self._client.request("POST", "/webhooks", body=body)

    def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return self._client.request_paginated("GET", "/webhooks", query={"page": page, "limit": limit})

    def update(
        self,
        webhook_id: str,
        *,
        url: str | None = None,
        events: list[str] | None = None,
        enabled: bool | None = None,
        retry_config: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({"url": url, "events": events, "enabled": enabled, "retry_config": retry_config})
        return self._client.request("PUT", f"/webhooks/{webhook_id}", body=body)

    def delete(self, webhook_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/webhooks/{webhook_id}")

    def test(self, webhook_id: str, *, event_type: str | None = None) -> dict[str, Any]:
        body = _filter_none({"event_type": event_type})
        return self._client.request("POST", f"/webhooks/{webhook_id}/test", body=body or None)

    def get_logs(self, webhook_id: str) -> list[dict[str, Any]]:
        return self._client.request_list("GET", f"/webhooks/{webhook_id}/logs")


class AsyncWebhooks(AsyncResource):
    async def create(self, *, url: str, events: list[str], session_id: str | None = None) -> dict[str, Any]:
        body = _filter_none({"url": url, "events": events, "session_id": session_id})
        return await self._client.request("POST", "/webhooks", body=body)

    async def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return await self._client.request_paginated("GET", "/webhooks", query={"page": page, "limit": limit})

    async def update(
        self,
        webhook_id: str,
        *,
        url: str | None = None,
        events: list[str] | None = None,
        enabled: bool | None = None,
        retry_config: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({"url": url, "events": events, "enabled": enabled, "retry_config": retry_config})
        return await self._client.request("PUT", f"/webhooks/{webhook_id}", body=body)

    async def delete(self, webhook_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/webhooks/{webhook_id}")

    async def test(self, webhook_id: str, *, event_type: str | None = None) -> dict[str, Any]:
        body = _filter_none({"event_type": event_type})
        return await self._client.request("POST", f"/webhooks/{webhook_id}/test", body=body or None)

    async def get_logs(self, webhook_id: str) -> list[dict[str, Any]]:
        return await self._client.request_list("GET", f"/webhooks/{webhook_id}/logs")



from __future__ import annotations

from typing import Any

from wazen._core._http_client import AsyncHttpClient
from wazen.resources import (
    AsyncAccount,
    AsyncApiKeys,
    AsyncChannels,
    AsyncContacts,
    AsyncGroups,
    AsyncMessages,
    AsyncSessions,
    AsyncWarming,
    AsyncWebhooks,
)

_DEFAULT_BASE_URL = "https://wazen.dev/api/v1"
_DEFAULT_TIMEOUT = 30


class AsyncWazen:
    """Wazen API client (asynchronous)."""

    sessions: AsyncSessions
    messages: AsyncMessages
    contacts: AsyncContacts
    groups: AsyncGroups
    channels: AsyncChannels
    warming: AsyncWarming
    webhooks: AsyncWebhooks
    account: AsyncAccount
    api_keys: AsyncApiKeys

    def __init__(
        self,
        api_key: str,
        *,
        base_url: str = _DEFAULT_BASE_URL,
        timeout: float = _DEFAULT_TIMEOUT,
    ) -> None:
        if not api_key or not isinstance(api_key, str):
            raise ValueError("API key is required. Pass your Wazen API key as the first argument.")

        self._client = AsyncHttpClient(api_key, base_url, timeout)

        self.sessions = AsyncSessions(self._client)
        self.messages = AsyncMessages(self._client)
        self.contacts = AsyncContacts(self._client)
        self.groups = AsyncGroups(self._client)
        self.channels = AsyncChannels(self._client)
        self.warming = AsyncWarming(self._client)
        self.webhooks = AsyncWebhooks(self._client)
        self.account = AsyncAccount(self._client)
        self.api_keys = AsyncApiKeys(self._client)

    async def close(self) -> None:
        await self._client.close()

    async def __aenter__(self) -> AsyncWazen:
        return self

    async def __aexit__(self, *args: Any) -> None:
        await self.close()



from __future__ import annotations

from typing import Any

from wazen.resources._base import AsyncResource, SyncResource


class Account(SyncResource):
    def get(self) -> dict[str, Any]:
        return self._client.request("GET", "/account")

    def get_usage(self) -> dict[str, Any]:
        return self._client.request("GET", "/usage")


class AsyncAccount(AsyncResource):
    async def get(self) -> dict[str, Any]:
        return await self._client.request("GET", "/account")

    async def get_usage(self) -> dict[str, Any]:
        return await self._client.request("GET", "/usage")



from __future__ import annotations

from typing import TYPE_CHECKING, Any

if TYPE_CHECKING:
    from wazen._core._http_client import AsyncHttpClient, SyncHttpClient


def _filter_none(d: dict[str, Any]) -> dict[str, Any]:
    return {k: v for k, v in d.items() if v is not None}


class SyncResource:
    def __init__(self, client: SyncHttpClient) -> None:
        self._client = client


class AsyncResource:
    def __init__(self, client: AsyncHttpClient) -> None:
        self._client = client



from wazen._core._errors import WazenApiError, WazenNetworkError, WazenTimeoutError
from wazen._core._types import PaginatedResponse

__all__ = [
    "WazenApiError",
    "WazenTimeoutError",
    "WazenNetworkError",
    "PaginatedResponse",
]



from __future__ import annotations


class WazenApiError(Exception):
    """Raised when the Wazen API returns an error response."""

    def __init__(
        self,
        message: str,
        status_code: int,
        error_code: str,
        request_id: str = "",
        details: object = None,
    ) -> None:
        super().__init__(message)
        self._message = message
        self.status_code = status_code
        self.error_code = error_code
        self.request_id = request_id
        self.details = details

    @property
    def message(self) -> str:
        return self._message

    def __repr__(self) -> str:
        return (
            f"WazenApiError(status_code={self.status_code}, "
            f"error_code={self.error_code!r}, message={self._message!r})"
        )


class WazenTimeoutError(Exception):
    """Raised when a request exceeds the configured timeout."""

    def __init__(self, timeout: float) -> None:
        super().__init__(f"Request timed out after {timeout}s")


class WazenNetworkError(Exception):
    """Raised when a network error prevents the request from completing."""

    def __init__(self, cause: Exception | None = None) -> None:
        msg = str(cause) if cause else "Network request failed"
        super().__init__(msg)
        self.__cause__ = cause



from __future__ import annotations

from typing import Any

from wazen._core._types import PaginatedResponse
from wazen.resources._base import AsyncResource, SyncResource, _filter_none


class Sessions(SyncResource):
    def create(self, *, phone_number: str | None = None) -> dict[str, Any]:
        body = _filter_none({"phone_number": phone_number})
        return self._client.request("POST", "/sessions", body=body or None)

    def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return self._client.request_paginated("GET", "/sessions", query={"page": page, "limit": limit})

    def get(self, session_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}")

    def delete(self, session_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}")

    def restart(self, session_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/restart")

    def get_qr(self, session_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/qr")

    def factory_reset(self, session_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/factory-reset")


class AsyncSessions(AsyncResource):
    async def create(self, *, phone_number: str | None = None) -> dict[str, Any]:
        body = _filter_none({"phone_number": phone_number})
        return await self._client.request("POST", "/sessions", body=body or None)

    async def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return await self._client.request_paginated("GET", "/sessions", query={"page": page, "limit": limit})

    async def get(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}")

    async def delete(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}")

    async def restart(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/restart")

    async def get_qr(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/qr")

    async def factory_reset(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/factory-reset")



from wazen.resources._account import Account, AsyncAccount
from wazen.resources._api_keys import ApiKeys, AsyncApiKeys
from wazen.resources._base import AsyncResource, SyncResource
from wazen.resources._channels import AsyncChannels, Channels
from wazen.resources._contacts import AsyncContacts, Contacts
from wazen.resources._groups import AsyncGroups, Groups
from wazen.resources._messages import AsyncMessages, Messages
from wazen.resources._sessions import AsyncSessions, Sessions
from wazen.resources._warming import AsyncWarming, Warming
from wazen.resources._webhooks import AsyncWebhooks, Webhooks

__all__ = [
    "SyncResource",
    "AsyncResource",
    "Sessions",
    "AsyncSessions",
    "Messages",
    "AsyncMessages",
    "Contacts",
    "AsyncContacts",
    "Groups",
    "AsyncGroups",
    "Channels",
    "AsyncChannels",
    "Warming",
    "AsyncWarming",
    "Webhooks",
    "AsyncWebhooks",
    "Account",
    "AsyncAccount",
    "ApiKeys",
    "AsyncApiKeys",
]



from __future__ import annotations

from typing import Any

from wazen.resources._base import AsyncResource, SyncResource, _filter_none


class Groups(SyncResource):
    def list(self, session_id: str) -> list[dict[str, Any]]:
        return self._client.request_list("GET", f"/sessions/{session_id}/groups")

    def create(self, session_id: str, *, subject: str, participants: list[str]) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/groups", body={"subject": subject, "participants": participants})

    def get(self, session_id: str, group_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/groups/{group_id}")

    def update(self, session_id: str, group_id: str, *, subject: str | None = None, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"subject": subject, "description": description})
        return self._client.request("PUT", f"/sessions/{session_id}/groups/{group_id}", body=body)

    def leave(self, session_id: str, group_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/groups/{group_id}")

    def manage_participants(self, session_id: str, group_id: str, *, action: str, participants: list[str]) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/participants", body={"action": action, "participants": participants})

    def update_settings(
        self,
        session_id: str,
        group_id: str,
        *,
        setting: str | None = None,
        ephemeral: int | None = None,
        member_add_mode: str | None = None,
        join_approval: str | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({"setting": setting, "ephemeral": ephemeral, "member_add_mode": member_add_mode, "join_approval": join_approval})
        return self._client.request("PUT", f"/sessions/{session_id}/groups/{group_id}/settings", body=body)

    def send_message(self, session_id: str, group_id: str, *, type: str, content: str | None = None, media_url: str | None = None) -> dict[str, Any]:
        body = _filter_none({"type": type, "content": content, "media_url": media_url})
        return self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/messages", body=body)

    def get_invite(self, session_id: str, group_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/groups/{group_id}/invite")

    def revoke_invite(self, session_id: str, group_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/groups/{group_id}/invite")

    def get_requests(self, session_id: str, group_id: str) -> list[dict[str, Any]]:
        return self._client.request_list("GET", f"/sessions/{session_id}/groups/{group_id}/requests")

    def manage_requests(self, session_id: str, group_id: str, *, participants: list[str], action: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/requests", body={"participants": participants, "action": action})

    def get_invite_info(self, session_id: str, *, code: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/groups/invite-info", query={"code": code})

    def join(self, session_id: str, *, code: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/groups/join", body={"code": code})


class AsyncGroups(AsyncResource):
    async def list(self, session_id: str) -> list[dict[str, Any]]:
        return await self._client.request_list("GET", f"/sessions/{session_id}/groups")

    async def create(self, session_id: str, *, subject: str, participants: list[str]) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/groups", body={"subject": subject, "participants": participants})

    async def get(self, session_id: str, group_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/groups/{group_id}")

    async def update(self, session_id: str, group_id: str, *, subject: str | None = None, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"subject": subject, "description": description})
        return await self._client.request("PUT", f"/sessions/{session_id}/groups/{group_id}", body=body)

    async def leave(self, session_id: str, group_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/groups/{group_id}")

    async def manage_participants(self, session_id: str, group_id: str, *, action: str, participants: list[str]) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/participants", body={"action": action, "participants": participants})

    async def update_settings(
        self,
        session_id: str,
        group_id: str,
        *,
        setting: str | None = None,
        ephemeral: int | None = None,
        member_add_mode: str | None = None,
        join_approval: str | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({"setting": setting, "ephemeral": ephemeral, "member_add_mode": member_add_mode, "join_approval": join_approval})
        return await self._client.request("PUT", f"/sessions/{session_id}/groups/{group_id}/settings", body=body)

    async def send_message(self, session_id: str, group_id: str, *, type: str, content: str | None = None, media_url: str | None = None) -> dict[str, Any]:
        body = _filter_none({"type": type, "content": content, "media_url": media_url})
        return await self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/messages", body=body)

    async def get_invite(self, session_id: str, group_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/groups/{group_id}/invite")

    async def revoke_invite(self, session_id: str, group_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/groups/{group_id}/invite")

    async def get_requests(self, session_id: str, group_id: str) -> list[dict[str, Any]]:
        return await self._client.request_list("GET", f"/sessions/{session_id}/groups/{group_id}/requests")

    async def manage_requests(self, session_id: str, group_id: str, *, participants: list[str], action: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/groups/{group_id}/requests", body={"participants": participants, "action": action})

    async def get_invite_info(self, session_id: str, *, code: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/groups/invite-info", query={"code": code})

    async def join(self, session_id: str, *, code: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/groups/join", body={"code": code})



from __future__ import annotations

from typing import Any


class PaginatedResponse:
    """Paginated list response with data and pagination metadata."""

    def __init__(self, data: list[dict[str, Any]], pagination: dict[str, Any]) -> None:
        self.data = data
        self.pagination = pagination

    def __repr__(self) -> str:
        return (
            f"PaginatedResponse(data=[...{len(self.data)} items], "
            f"pagination={self.pagination})"
        )



from __future__ import annotations

from typing import Any

import httpx

from wazen._core._errors import WazenApiError, WazenNetworkError, WazenTimeoutError
from wazen._core._types import PaginatedResponse
from wazen._version import __version__

_USER_AGENT = f"wazen-python/{__version__}"


def _filter_none(d: dict[str, Any]) -> dict[str, Any]:
    return {k: v for k, v in d.items() if v is not None}


def _build_query(params: dict[str, Any] | None) -> dict[str, str] | None:
    if not params:
        return None
    filtered = {k: str(v) for k, v in params.items() if v is not None}
    return filtered or None


def _handle_response(response: httpx.Response) -> dict[str, Any]:
    try:
        body = response.json()
    except Exception:
        raise WazenApiError(
            f"Unexpected response format (HTTP {response.status_code})",
            response.status_code,
            "INTERNAL_ERROR",
        )

    if not body.get("success"):
        error = body.get("error", {})
        meta = body.get("meta", {})
        raise WazenApiError(
            message=error.get("message", "Unknown error"),
            status_code=response.status_code,
            error_code=error.get("code", "INTERNAL_ERROR"),
            request_id=meta.get("request_id", ""),
            details=error.get("details"),
        )

    return body


class SyncHttpClient:
    def __init__(self, api_key: str, base_url: str, timeout: float) -> None:
        self._timeout = timeout
        self._client = httpx.Client(
            base_url=base_url,
            timeout=timeout,
            headers={
                "Authorization": f"Bearer {api_key}",
                "Accept": "application/json",
                "User-Agent": _USER_AGENT,
            },
        )

    def request(
        self,
        method: str,
        path: str,
        *,
        body: dict[str, Any] | None = None,
        query: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        body = _handle_response(self._execute(method, path, body=body, query=query))
        return body["data"]

    def request_paginated(
        self,
        method: str,
        path: str,
        *,
        query: dict[str, Any] | None = None,
    ) -> PaginatedResponse:
        body = _handle_response(self._execute(method, path, query=query))
        pagination = body.get("meta", {}).get("pagination", {})
        return PaginatedResponse(data=body["data"], pagination=pagination)

    def request_list(
        self,
        method: str,
        path: str,
        *,
        query: dict[str, Any] | None = None,
    ) -> list[dict[str, Any]]:
        body = _handle_response(self._execute(method, path, query=query))
        return body["data"]

    def close(self) -> None:
        self._client.close()

    def _execute(
        self,
        method: str,
        path: str,
        *,
        body: dict[str, Any] | None = None,
        query: dict[str, Any] | None = None,
    ) -> httpx.Response:
        json_body = _filter_none(body) if body else None
        params = _build_query(query)
        try:
            return self._client.request(method, path, json=json_body, params=params)
        except httpx.TimeoutException:
            raise WazenTimeoutError(self._timeout)
        except httpx.HTTPError as exc:
            raise WazenNetworkError(exc)


class AsyncHttpClient:
    def __init__(self, api_key: str, base_url: str, timeout: float) -> None:
        self._timeout = timeout
        self._client = httpx.AsyncClient(
            base_url=base_url,
            timeout=timeout,
            headers={
                "Authorization": f"Bearer {api_key}",
                "Accept": "application/json",
                "User-Agent": _USER_AGENT,
            },
        )

    async def request(
        self,
        method: str,
        path: str,
        *,
        body: dict[str, Any] | None = None,
        query: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        body = _handle_response(
            await self._execute(method, path, body=body, query=query)
        )
        return body["data"]

    async def request_paginated(
        self,
        method: str,
        path: str,
        *,
        query: dict[str, Any] | None = None,
    ) -> PaginatedResponse:
        body = _handle_response(await self._execute(method, path, query=query))
        pagination = body.get("meta", {}).get("pagination", {})
        return PaginatedResponse(data=body["data"], pagination=pagination)

    async def request_list(
        self,
        method: str,
        path: str,
        *,
        query: dict[str, Any] | None = None,
    ) -> list[dict[str, Any]]:
        body = _handle_response(await self._execute(method, path, query=query))
        return body["data"]

    async def close(self) -> None:
        await self._client.aclose()

    async def _execute(
        self,
        method: str,
        path: str,
        *,
        body: dict[str, Any] | None = None,
        query: dict[str, Any] | None = None,
    ) -> httpx.Response:
        json_body = _filter_none(body) if body else None
        params = _build_query(query)
        try:
            return await self._client.request(
                method, path, json=json_body, params=params
            )
        except httpx.TimeoutException:
            raise WazenTimeoutError(self._timeout)
        except httpx.HTTPError as exc:
            raise WazenNetworkError(exc)



from __future__ import annotations

from typing import Any

from wazen.resources._base import AsyncResource, SyncResource, _filter_none


class Channels(SyncResource):
    def create(self, session_id: str, *, name: str, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"name": name, "description": description})
        return self._client.request("POST", f"/sessions/{session_id}/channels", body=body)

    def lookup(self, session_id: str, *, jid: str | None = None, invite: str | None = None) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/channels", query={"jid": jid, "invite": invite})

    def get(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/channels/{channel_id}")

    def update(self, session_id: str, channel_id: str, *, name: str | None = None, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"name": name, "description": description})
        return self._client.request("PUT", f"/sessions/{session_id}/channels/{channel_id}", body=body)

    def delete(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}")

    def send_message(self, session_id: str, channel_id: str, *, type: str, content: str | None = None, media_url: str | None = None) -> dict[str, Any]:
        body = _filter_none({"type": type, "content": content, "media_url": media_url})
        return self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/messages", body=body)

    def list_messages(self, session_id: str, channel_id: str, *, count: int | None = None, since: int | None = None, after: int | None = None) -> list[dict[str, Any]]:
        return self._client.request_list("GET", f"/sessions/{session_id}/channels/{channel_id}/messages", query={"count": count, "since": since, "after": after})

    def react(self, session_id: str, channel_id: str, message_id: str, *, reaction: str | None = None) -> dict[str, Any]:
        body = _filter_none({"reaction": reaction}) if reaction is not None else None
        return self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/messages/{message_id}/react", body=body)

    def follow(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/follow")

    def unfollow(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}/follow")

    def mute(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/mute")

    def unmute(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}/mute")


class AsyncChannels(AsyncResource):
    async def create(self, session_id: str, *, name: str, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"name": name, "description": description})
        return await self._client.request("POST", f"/sessions/{session_id}/channels", body=body)

    async def lookup(self, session_id: str, *, jid: str | None = None, invite: str | None = None) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/channels", query={"jid": jid, "invite": invite})

    async def get(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/channels/{channel_id}")

    async def update(self, session_id: str, channel_id: str, *, name: str | None = None, description: str | None = None) -> dict[str, Any]:
        body = _filter_none({"name": name, "description": description})
        return await self._client.request("PUT", f"/sessions/{session_id}/channels/{channel_id}", body=body)

    async def delete(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}")

    async def send_message(self, session_id: str, channel_id: str, *, type: str, content: str | None = None, media_url: str | None = None) -> dict[str, Any]:
        body = _filter_none({"type": type, "content": content, "media_url": media_url})
        return await self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/messages", body=body)

    async def list_messages(self, session_id: str, channel_id: str, *, count: int | None = None, since: int | None = None, after: int | None = None) -> list[dict[str, Any]]:
        return await self._client.request_list("GET", f"/sessions/{session_id}/channels/{channel_id}/messages", query={"count": count, "since": since, "after": after})

    async def react(self, session_id: str, channel_id: str, message_id: str, *, reaction: str | None = None) -> dict[str, Any]:
        body = _filter_none({"reaction": reaction}) if reaction is not None else None
        return await self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/messages/{message_id}/react", body=body)

    async def follow(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/follow")

    async def unfollow(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}/follow")

    async def mute(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/channels/{channel_id}/mute")

    async def unmute(self, session_id: str, channel_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/channels/{channel_id}/mute")



from __future__ import annotations

from typing import Any

from wazen.resources._base import AsyncResource, SyncResource


class Warming(SyncResource):
    def start(self, session_id: str, *, contacts: list[dict[str, Any]]) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/warming", body={"contacts": contacts})

    def get_status(self, session_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/warming")

    def pause(self, session_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/warming/pause")

    def resume(self, session_id: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/warming/resume")

    def cancel(self, session_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/sessions/{session_id}/warming")


class AsyncWarming(AsyncResource):
    async def start(self, session_id: str, *, contacts: list[dict[str, Any]]) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/warming", body={"contacts": contacts})

    async def get_status(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/warming")

    async def pause(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/warming/pause")

    async def resume(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/warming/resume")

    async def cancel(self, session_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/sessions/{session_id}/warming")



from __future__ import annotations

from typing import Any

from wazen._core._types import PaginatedResponse
from wazen.resources._base import AsyncResource, SyncResource


class ApiKeys(SyncResource):
    def create(self, *, name: str) -> dict[str, Any]:
        return self._client.request("POST", "/api-keys", body={"name": name})

    def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return self._client.request_paginated("GET", "/api-keys", query={"page": page, "limit": limit})

    def revoke(self, key_id: str) -> dict[str, Any]:
        return self._client.request("DELETE", f"/api-keys/{key_id}")


class AsyncApiKeys(AsyncResource):
    async def create(self, *, name: str) -> dict[str, Any]:
        return await self._client.request("POST", "/api-keys", body={"name": name})

    async def list(self, *, page: int | None = None, limit: int | None = None) -> PaginatedResponse:
        return await self._client.request_paginated("GET", "/api-keys", query={"page": page, "limit": limit})

    async def revoke(self, key_id: str) -> dict[str, Any]:
        return await self._client.request("DELETE", f"/api-keys/{key_id}")



from __future__ import annotations

from typing import Any

from wazen._core._http_client import SyncHttpClient
from wazen.resources import (
    Account,
    ApiKeys,
    Channels,
    Contacts,
    Groups,
    Messages,
    Sessions,
    Warming,
    Webhooks,
)

_DEFAULT_BASE_URL = "https://wazen.dev/api/v1"
_DEFAULT_TIMEOUT = 30


class Wazen:
    """Wazen API client (synchronous)."""

    sessions: Sessions
    messages: Messages
    contacts: Contacts
    groups: Groups
    channels: Channels
    warming: Warming
    webhooks: Webhooks
    account: Account
    api_keys: ApiKeys

    def __init__(
        self,
        api_key: str,
        *,
        base_url: str = _DEFAULT_BASE_URL,
        timeout: float = _DEFAULT_TIMEOUT,
    ) -> None:
        if not api_key or not isinstance(api_key, str):
            raise ValueError("API key is required. Pass your Wazen API key as the first argument.")

        self._client = SyncHttpClient(api_key, base_url, timeout)

        self.sessions = Sessions(self._client)
        self.messages = Messages(self._client)
        self.contacts = Contacts(self._client)
        self.groups = Groups(self._client)
        self.channels = Channels(self._client)
        self.warming = Warming(self._client)
        self.webhooks = Webhooks(self._client)
        self.account = Account(self._client)
        self.api_keys = ApiKeys(self._client)

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Wazen:
        return self

    def __exit__(self, *args: Any) -> None:
        self.close()



from __future__ import annotations

from typing import Any

from wazen._core._types import PaginatedResponse
from wazen.resources._base import AsyncResource, SyncResource, _filter_none


class Messages(SyncResource):
    def send(
        self,
        session_id: str,
        *,
        to: str,
        type: str,
        content: str | None = None,
        media_url: str | None = None,
        media_base64: str | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({
            "to": to,
            "type": type,
            "content": content,
            "media_url": media_url,
            "media_base64": media_base64,
        })
        return self._client.request("POST", f"/sessions/{session_id}/messages", body=body)

    def list(
        self,
        session_id: str,
        *,
        page: int | None = None,
        limit: int | None = None,
        direction: str | None = None,
        type: str | None = None,
    ) -> PaginatedResponse:
        return self._client.request_paginated(
            "GET",
            f"/sessions/{session_id}/messages",
            query={"page": page, "limit": limit, "direction": direction, "type": type},
        )

    def get(self, session_id: str, message_id: str) -> dict[str, Any]:
        return self._client.request("GET", f"/sessions/{session_id}/messages/{message_id}")


class AsyncMessages(AsyncResource):
    async def send(
        self,
        session_id: str,
        *,
        to: str,
        type: str,
        content: str | None = None,
        media_url: str | None = None,
        media_base64: str | None = None,
    ) -> dict[str, Any]:
        body = _filter_none({
            "to": to,
            "type": type,
            "content": content,
            "media_url": media_url,
            "media_base64": media_base64,
        })
        return await self._client.request("POST", f"/sessions/{session_id}/messages", body=body)

    async def list(
        self,
        session_id: str,
        *,
        page: int | None = None,
        limit: int | None = None,
        direction: str | None = None,
        type: str | None = None,
    ) -> PaginatedResponse:
        return await self._client.request_paginated(
            "GET",
            f"/sessions/{session_id}/messages",
            query={"page": page, "limit": limit, "direction": direction, "type": type},
        )

    async def get(self, session_id: str, message_id: str) -> dict[str, Any]:
        return await self._client.request("GET", f"/sessions/{session_id}/messages/{message_id}")



from __future__ import annotations

from typing import Any

from wazen.resources._base import AsyncResource, SyncResource


class Contacts(SyncResource):
    def check(self, session_id: str, *, phone: str) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/contacts/check", body={"phone": phone})

    def bulk_check(self, session_id: str, *, phones: list[str]) -> dict[str, Any]:
        return self._client.request("POST", f"/sessions/{session_id}/contacts/bulk-check", body={"phones": phones})


class AsyncContacts(AsyncResource):
    async def check(self, session_id: str, *, phone: str) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/contacts/check", body={"phone": phone})

    async def bulk_check(self, session_id: str, *, phones: list[str]) -> dict[str, Any]:
        return await self._client.request("POST", f"/sessions/{session_id}/contacts/bulk-check", body={"phones": phones})
